aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorandroid-autoroll <android-autoroll@skia-public.iam.gserviceaccount.com>2023-04-21 14:06:37 +0000
committerAutomerger Merge Worker <android-build-automerger-merge-worker@system.gserviceaccount.com>2023-04-21 14:06:37 +0000
commit7ab90c1c379aef3ca7534c7b8fd00eda312f6e2e (patch)
tree0ea7935a6266133f4e155e462fb2464a17530bbf
parent405c1d7ccf7a9f2ece615c03f84faed3c8b97de7 (diff)
parent7dacf20525a5019b429371f410a757bb82096a68 (diff)
downloadangle-7ab90c1c379aef3ca7534c7b8fd00eda312f6e2e.tar.gz
Roll ANGLE from 1300591bb370 to 6bae26f6f0f3 (10 revisions) am: f821c57947 am: 7dacf20525
Original change: https://android-review.googlesource.com/c/platform/external/angle/+/2552772 Change-Id: I838f9d3a471cafed0308a8c3b5545c01f19cca6a Signed-off-by: Automerger Merge Worker <android-build-automerger-merge-worker@system.gserviceaccount.com>
-rw-r--r--DEPS36
-rwxr-xr-xbuild/android/gyp/compile_java.py17
-rwxr-xr-xbuild/android/gyp/compile_resources.py6
-rwxr-xr-xbuild/android/gyp/turbine.py17
-rw-r--r--build/android/gyp/util/resource_utils.py10
-rw-r--r--build/android/gyp/util/resources_parser.py8
-rwxr-xr-xbuild/android/gyp/write_build_config.py9
-rw-r--r--build/config/android/internal_rules.gni5
-rw-r--r--build/config/android/rules.gni3
-rw-r--r--build/config/siso/remote_exec_wrapper.star10
-rw-r--r--build/fuchsia/test/common.py33
-rw-r--r--build/fuchsia/test/ffx_emulator.py12
-rwxr-xr-xbuild/fuchsia/test/flash_device.py2
-rwxr-xr-xbuild/fuchsia/test/flash_device_unittests.py3
-rw-r--r--build/rust/std/BUILD.gn12
-rw-r--r--build/util/LASTCHANGE2
-rw-r--r--build/util/LASTCHANGE.committime2
-rw-r--r--infra/specs/angle.json110
-rw-r--r--infra/specs/test_suites.pyl13
-rw-r--r--scripts/code_generation_hashes/GL_CTS_(dEQP)_build_files.json2
-rw-r--r--scripts/code_generation_hashes/Test_spec_JSON.json4
-rw-r--r--src/common/base/anglebase/sha1.h1
-rw-r--r--src/libANGLE/Context.cpp7
-rw-r--r--src/libANGLE/renderer/metal/mtl_utils.mm2
-rw-r--r--src/libANGLE/renderer/vulkan/ContextVk.cpp9
-rw-r--r--src/tests/BUILD.gn11
-rw-r--r--src/tests/angle_end2end_tests_expectations.txt2
-rw-r--r--third_party/abseil-cpp/absl/base/options.h2
-rw-r--r--third_party/abseil-cpp/patches/0001-Turn-on-hardened-mode.patch9
-rw-r--r--third_party/vulkan-deps/DEPS8
-rw-r--r--third_party/vulkan-deps/glslang/src/.appveyor.yml108
-rw-r--r--third_party/vulkan-deps/glslang/src/Test/baseResults/300layout.vert.out2
-rw-r--r--third_party/vulkan-deps/glslang/src/glslang/MachineIndependent/ParseHelper.cpp2
-rw-r--r--third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan.hpp2
-rw-r--r--third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan_core.h2
35 files changed, 145 insertions, 338 deletions
diff --git a/DEPS b/DEPS
index a5a33285f4..977e3c65e3 100644
--- a/DEPS
+++ b/DEPS
@@ -43,13 +43,13 @@ vars = {
'checkout_angle_mesa': False,
# Version of Chromium our Chromium-based DEPS are mirrored from.
- 'chromium_revision': '943c805072c1998b60f41d226936e8e0976f0b03',
+ 'chromium_revision': '45a2890ceb31177676547f2932b652f4377cb446',
# We never want to checkout chromium,
# but need a dummy DEPS entry for the autoroller
'dummy_checkout_chromium': False,
# Current revision of VK-GL-CTS (a.k.a dEQP).
- 'vk_gl_cts_revision': 'a3d054bf72abd5060f81f7437cac457cdccaf002',
+ 'vk_gl_cts_revision': 'b1e5b9348e77a8df9e356ff632d7b7117553f053',
# Current revision of googletest.
# Note: this dep cannot be auto-rolled b/c of nesting.
@@ -88,11 +88,11 @@ vars = {
# Three lines of non-changing comments so that
# the commit queue can handle CLs rolling catapult
# and whatever else without interference from each other.
- 'catapult_revision': '843ad30cc39880b519c0f72459c6acf6df93b2ce',
+ 'catapult_revision': 'f7a8b55f34deeafae172884f97b312f1b18fd2db',
# the commit queue can handle CLs rolling Fuchsia sdk
# and whatever else without interference from each other.
- 'fuchsia_version': 'version:12.20230419.3.1',
+ 'fuchsia_version': 'version:12.20230420.3.1',
# Three lines of non-changing comments so that
# the commit queue can handle CLs rolling luci-go
@@ -140,7 +140,7 @@ vars = {
deps = {
'build': {
- 'url': '{chromium_git}/chromium/src/build.git@da8c6824432694a6d2de51fae66134e79a5715d9',
+ 'url': '{chromium_git}/chromium/src/build.git@f78fc195a7798b13df0c7d13ebb863e21c6905d3',
'condition': 'not build_with_chromium',
},
@@ -182,7 +182,7 @@ deps = {
},
'buildtools/third_party/libc++abi/trunk': {
- 'url': '{chromium_git}/external/github.com/llvm/llvm-project/libcxxabi.git@559b8716f34c57929dfe658435adaa467f1b4de7',
+ 'url': '{chromium_git}/external/github.com/llvm/llvm-project/libcxxabi.git@a64df6cce230b9d4931b32eeae44ec1af2b63caa',
'condition': 'not build_with_chromium',
},
@@ -203,12 +203,12 @@ deps = {
},
'testing': {
- 'url': '{chromium_git}/chromium/src/testing@fc28ec63d9b3808b9b9eef92a1e0737a192af9ac',
+ 'url': '{chromium_git}/chromium/src/testing@da88a644b4f9d7fcac72b01ae08d1b3a1761a9e7',
'condition': 'not build_with_chromium',
},
'third_party/abseil-cpp': {
- 'url': '{chromium_git}/chromium/src/third_party/abseil-cpp@65b93e7bf3d909d6787960c44e14908abc41a77a',
+ 'url': '{chromium_git}/chromium/src/third_party/abseil-cpp@3c6eb3447cfde0d5317c776d8853e4aea25bec95',
'condition': 'not build_with_chromium',
},
@@ -254,7 +254,7 @@ deps = {
'packages': [
{
'package': 'chromium/third_party/android_build_tools/lint',
- 'version': '-QeaXYm6b9vGTpMVBhnqlwODS7YvC3vNdvA0KVEz0TwC',
+ 'version': '667xWoGhzEgkSGU0T6WsZwwXOg1PTUw0b1yjbLunR6kC',
},
],
'condition': 'checkout_android and not build_with_chromium',
@@ -265,7 +265,7 @@ deps = {
'packages': [
{
'package': 'chromium/third_party/android_build_tools/manifest_merger',
- 'version': 'zrC8AzHP0aIX3PNRmyIUO6hidQryUwSv65YE8KQEZa0C',
+ 'version': '1g5VzjyIYFR1uY6iwEOLv8aZp-OQJQc5W2U-dPyg97IC',
},
],
'condition': 'checkout_android and not build_with_chromium',
@@ -380,7 +380,7 @@ deps = {
},
'third_party/depot_tools': {
- 'url': '{chromium_git}/chromium/tools/depot_tools.git@607284d7190a11b77dba7567bc867d63329ea2ba',
+ 'url': '{chromium_git}/chromium/tools/depot_tools.git@dec6fddc86f66df64d698ebf402ef83f4e57843e',
'condition': 'not build_with_chromium',
},
@@ -553,7 +553,7 @@ deps = {
},
'third_party/protobuf': {
- 'url': '{chromium_git}/chromium/src/third_party/protobuf@57396ed0a2818b1ad68101832eecf53a38cd321f',
+ 'url': '{chromium_git}/chromium/src/third_party/protobuf@46428dc4d33a13acde7b2bce4ee222f9fb0e0f32',
'condition': 'not build_with_chromium',
},
@@ -588,7 +588,7 @@ deps = {
'packages': [
{
'package': 'chromium/third_party/r8',
- 'version': '8NFHPxUiooKTw4bFz4TUVhDuzuDJi5xkLGaCtjX3MsAC',
+ 'version': 'lCPwGCprok6_HL-cm8IStyKRbdF6wcFvXg74WOk3mmcC',
},
],
'condition': 'checkout_android and not build_with_chromium',
@@ -644,7 +644,7 @@ deps = {
},
'third_party/vulkan-deps': {
- 'url': '{chromium_git}/vulkan-deps@c1d27abff170d2571f45b8b73832cc079ba4baea',
+ 'url': '{chromium_git}/vulkan-deps@bfd1e43ef9d61979742e443de21a71c4a1f95919',
'condition': 'not build_with_chromium',
},
@@ -669,7 +669,7 @@ deps = {
},
'tools/clang': {
- 'url': '{chromium_git}/chromium/src/tools/clang.git@03a7fcfc3203a4b9eb107bc7ac86fa19d6cd5bbd',
+ 'url': '{chromium_git}/chromium/src/tools/clang.git@a443ff055ede11a8062c0b3f4fe0cd877ec670b2',
'condition': 'not build_with_chromium',
},
@@ -700,7 +700,7 @@ deps = {
},
'tools/mb': {
- 'url': '{chromium_git}/chromium/src/tools/mb@f9faec9819df8d3de604b63f7880cfe9575c49f2',
+ 'url': '{chromium_git}/chromium/src/tools/mb@f070c271604924c408106974fb2708f2ef8de493',
'condition': 'not build_with_chromium',
},
@@ -710,12 +710,12 @@ deps = {
},
'tools/memory': {
- 'url': '{chromium_git}/chromium/src/tools/memory@a295e5b2886b8f8b6e00a967447c7ed4e5f9e351',
+ 'url': '{chromium_git}/chromium/src/tools/memory@09f58c36cb63d3fd26bed8e3aca96d86ae03db91',
'condition': 'not build_with_chromium',
},
'tools/perf': {
- 'url': '{chromium_git}/chromium/src/tools/perf@18fde8dc95d85e6ed9f24ed5090aad3230b54deb',
+ 'url': '{chromium_git}/chromium/src/tools/perf@6b71dfeacbbde5887ea6cb458db97a91758c3fe8',
'condition': 'not build_with_chromium',
},
diff --git a/build/android/gyp/compile_java.py b/build/android/gyp/compile_java.py
index 3fc40ad8d1..69b89092b8 100755
--- a/build/android/gyp/compile_java.py
+++ b/build/android/gyp/compile_java.py
@@ -598,18 +598,11 @@ def _RunCompiler(changes,
logging.debug('Build command %s', cmd)
start = time.time()
- try:
- build_utils.CheckOutput(cmd,
- print_stdout=options.chromium_code,
- stdout_filter=process_javac_output_partial,
- stderr_filter=process_javac_output_partial,
- fail_on_output=options.warnings_as_errors)
- except build_utils.CalledProcessError as e:
- # Do not output stacktrace as it takes up space on gerrit UI, forcing
- # you to click though to find the actual compilation error. It's never
- # interesting to see the Python stacktrace for a Java compilation error.
- sys.stderr.write(e.output)
- sys.exit(1)
+ build_utils.CheckOutput(cmd,
+ print_stdout=options.chromium_code,
+ stdout_filter=process_javac_output_partial,
+ stderr_filter=process_javac_output_partial,
+ fail_on_output=options.warnings_as_errors)
end = time.time() - start
logging.info('Java compilation took %ss', end)
diff --git a/build/android/gyp/compile_resources.py b/build/android/gyp/compile_resources.py
index d3791af786..3b1fe73004 100755
--- a/build/android/gyp/compile_resources.py
+++ b/build/android/gyp/compile_resources.py
@@ -170,10 +170,6 @@ def _ParseArgs(args):
input_opts.add_argument(
'--webp-cache-dir', help='The directory to store webp image cache.')
input_opts.add_argument(
- '--no-xml-namespaces',
- action='store_true',
- help='Whether to strip xml namespaces from processed xml resources.')
- input_opts.add_argument(
'--is-bundle-module',
action='store_true',
help='Whether resources are being generated for a bundle module.')
@@ -769,7 +765,7 @@ def _PackageApk(options, build):
if options.shared_resources:
link_command.append('--shared-lib')
- if options.no_xml_namespaces:
+ if int(options.min_sdk_version) > 21:
link_command.append('--no-xml-namespaces')
if options.package_id:
diff --git a/build/android/gyp/turbine.py b/build/android/gyp/turbine.py
index 2de92f4704..00aa3106b6 100755
--- a/build/android/gyp/turbine.py
+++ b/build/android/gyp/turbine.py
@@ -135,18 +135,11 @@ def main(argv):
logging.debug('Command: %s', cmd)
start = time.time()
- try:
- build_utils.CheckOutput(cmd,
- print_stdout=True,
- stdout_filter=process_javac_output_partial,
- stderr_filter=process_javac_output_partial,
- fail_on_output=options.warnings_as_errors)
- except build_utils.CalledProcessError as e:
- # Do not output stacktrace as it takes up space on gerrit UI, forcing
- # you to click though to find the actual compilation error. It's never
- # interesting to see the Python stacktrace for a Java compilation error.
- sys.stderr.write(e.output)
- sys.exit(1)
+ build_utils.CheckOutput(cmd,
+ print_stdout=True,
+ stdout_filter=process_javac_output_partial,
+ stderr_filter=process_javac_output_partial,
+ fail_on_output=options.warnings_as_errors)
end = time.time() - start
logging.info('Header compilation took %ss', end)
if options.kotlin_jar_path:
diff --git a/build/android/gyp/util/resource_utils.py b/build/android/gyp/util/resource_utils.py
index 36d890417d..dac0ae7588 100644
--- a/build/android/gyp/util/resource_utils.py
+++ b/build/android/gyp/util/resource_utils.py
@@ -42,7 +42,7 @@ _ANDROID_TO_CHROMIUM_LANGUAGE_MAP = {
'no': 'nb', # 'no' is not a real language. http://crbug.com/920960
}
-_ALL_RESOURCE_TYPES = {
+ALL_RESOURCE_TYPES = {
'anim', 'animator', 'array', 'attr', 'bool', 'color', 'dimen', 'drawable',
'font', 'fraction', 'id', 'integer', 'interpolator', 'layout', 'macro',
'menu', 'mipmap', 'plurals', 'raw', 'string', 'style', 'styleable',
@@ -589,8 +589,8 @@ def CreateRJavaFiles(srcjar_dir,
else:
all_resources[entry_key] = entry
all_resources_by_type[entry.resource_type].append(entry)
- assert entry.resource_type in _ALL_RESOURCE_TYPES, (
- 'Unknown resource type: %s, add to _ALL_RESOURCE_TYPES!' %
+ assert entry.resource_type in ALL_RESOURCE_TYPES, (
+ 'Unknown resource type: %s, add to ALL_RESOURCE_TYPES!' %
entry.resource_type)
if custom_root_package_name:
@@ -666,7 +666,7 @@ public final class R {
return template.render(
package=package,
- resource_types=sorted(_ALL_RESOURCE_TYPES),
+ resource_types=sorted(ALL_RESOURCE_TYPES),
root_package=root_r_java_package,
has_on_resources_loaded=rjava_build_options.has_on_resources_loaded)
@@ -778,7 +778,7 @@ packageIdTransform);
lstrip_blocks=True)
return template.render(
package=package,
- resource_types=sorted(_ALL_RESOURCE_TYPES),
+ resource_types=sorted(ALL_RESOURCE_TYPES),
has_on_resources_loaded=rjava_build_options.has_on_resources_loaded,
fake_on_resources_loaded=rjava_build_options.fake_on_resources_loaded,
final_resources=final_resources_by_type,
diff --git a/build/android/gyp/util/resources_parser.py b/build/android/gyp/util/resources_parser.py
index 525e136243..86d85407d3 100644
--- a/build/android/gyp/util/resources_parser.py
+++ b/build/android/gyp/util/resources_parser.py
@@ -98,12 +98,18 @@ class RTxtGenerator:
if child.tag == 'declare-styleable':
ret.update(self._ParseDeclareStyleable(child))
else:
- if child.tag == 'item':
+ if child.tag in ('item', 'public'):
resource_type = child.attrib['type']
elif child.tag in ('array', 'integer-array', 'string-array'):
resource_type = 'array'
else:
resource_type = child.tag
+ parsed_element = ElementTree.tostring(child, encoding='unicode').strip()
+ assert resource_type in resource_utils.ALL_RESOURCE_TYPES, (
+ f'Infered resource type ({resource_type}) from xml entry '
+ f'({parsed_element}) (found in {xml_path}) is not listed in '
+ 'resource_utils.ALL_RESOURCE_TYPES. Teach resources_parser.py how '
+ 'to parse this entry and/or add to the list.')
name = _ResourceNameToJavaSymbol(child.attrib['name'])
ret.add(_TextSymbolEntry('int', resource_type, name, _DUMMY_RTXT_ID))
return ret
diff --git a/build/android/gyp/write_build_config.py b/build/android/gyp/write_build_config.py
index e64c62233a..7976dd89cc 100755
--- a/build/android/gyp/write_build_config.py
+++ b/build/android/gyp/write_build_config.py
@@ -2133,10 +2133,15 @@ def main(argv):
GetDepConfig(p) for p in GetAllDepsConfigsInOrder(
deps_configs_paths, filter_func=ExcludeRecursiveResourcesDeps)
]
+ # Manifests are listed from highest priority to lowest priority.
+ # Ensure directly manfifests come first, and then sort the rest by name.
+ # https://developer.android.com/build/manage-manifests#merge_priorities
config['extra_android_manifests'] = list(mergeable_android_manifests)
+ manifests_from_deps = []
for c in extra_manifest_deps:
- config['extra_android_manifests'].extend(
- c.get('mergeable_android_manifests', []))
+ manifests_from_deps += c.get('mergeable_android_manifests', [])
+ manifests_from_deps.sort(key=lambda p: (os.path.basename(p), p))
+ config['extra_android_manifests'] += manifests_from_deps
config['assets'], config['uncompressed_assets'], locale_paks = (
_MergeAssets(deps.All('android_assets')))
diff --git a/build/config/android/internal_rules.gni b/build/config/android/internal_rules.gni
index 45208354ea..f8dcfaedc9 100644
--- a/build/config/android/internal_rules.gni
+++ b/build/config/android/internal_rules.gni
@@ -2097,8 +2097,6 @@ if (enable_java_templates) {
#
# resource_values_filter_rules: (optional)
#
- # no_xml_namespaces: (optional)
- #
# png_to_webp: (optional)
# If true, convert all PNG resources (except 9-patch files) to WebP.
#
@@ -2177,9 +2175,6 @@ if (enable_java_templates) {
"--srcjar-out",
rebase_path(_final_srcjar_path, root_build_dir),
]
- if (defined(invoker.no_xml_namespaces) && invoker.no_xml_namespaces) {
- _args += [ "--no-xml-namespaces" ]
- }
if (defined(invoker.version_code)) {
_args += [
"--version-code",
diff --git a/build/config/android/rules.gni b/build/config/android/rules.gni
index 2c43a6488a..66ac5f962c 100644
--- a/build/config/android/rules.gni
+++ b/build/config/android/rules.gni
@@ -2747,7 +2747,6 @@ if (enable_java_templates && is_android) {
"expected_android_manifest_version_code_offset",
"manifest_package",
"max_sdk_version",
- "no_xml_namespaces",
"package_id",
"png_to_webp",
"r_java_root_package_name",
@@ -3632,7 +3631,6 @@ if (enable_java_templates && is_android) {
"min_sdk_version",
"native_lib_placeholders",
"never_incremental",
- "no_xml_namespaces",
"omit_dex",
"png_to_webp",
"post_process_package_resources_script",
@@ -3771,7 +3769,6 @@ if (enable_java_templates && is_android) {
"mergeable_android_manifests",
"module_name",
"native_lib_placeholders",
- "no_xml_namespaces",
"package_id",
"parent_module_target",
"png_to_webp",
diff --git a/build/config/siso/remote_exec_wrapper.star b/build/config/siso/remote_exec_wrapper.star
index c1a16b473c..96f816caf4 100644
--- a/build/config/siso/remote_exec_wrapper.star
+++ b/build/config/siso/remote_exec_wrapper.star
@@ -31,6 +31,16 @@ def __step_config(ctx, step_config):
"action": "(.*_)?cc",
"use_remote_exec_wrapper": True,
},
+ {
+ "name": "clang/objcxx",
+ "action": "(.*_)?objcxx",
+ "use_remote_exec_wrapper": True,
+ },
+ {
+ "name": "clang/objc",
+ "action": "(.*_)?objc",
+ "use_remote_exec_wrapper": True,
+ },
])
return step_config
diff --git a/build/fuchsia/test/ffx_emulator.py b/build/fuchsia/test/ffx_emulator.py
index 3860ec8abc..be473ccb92 100644
--- a/build/fuchsia/test/ffx_emulator.py
+++ b/build/fuchsia/test/ffx_emulator.py
@@ -108,16 +108,20 @@ class FfxEmulator(AbstractContextManager):
json.dump(ast.literal_eval(qemu_arm64_meta), f)
emu_command.extend(['--engine', 'qemu'])
- for _ in range(_EMU_COMMAND_RETRIES):
+ for i in range(_EMU_COMMAND_RETRIES):
# If the ffx daemon fails to establish a connection with
# the emulator after 85 seconds, that means the emulator
# failed to be brought up and a retry is needed.
# TODO(fxb/103540): Remove retry when start up issue is fixed.
try:
- run_ffx_command(emu_command,
- timeout=85,
- configs=['emu.start.timeout=90'])
+ # TODO(fxb/125872): Debug is added for examining flakiness.
+ configs = ['emu.start.timeout=90']
+ if i > 0:
+ logging.warning(
+ 'Emulator failed to start. Turning on debug')
+ configs.append('log.level=debug')
+ run_ffx_command(emu_command, timeout=85, configs=configs)
break
except (subprocess.TimeoutExpired, subprocess.CalledProcessError):
run_ffx_command(('emu', 'stop'))
diff --git a/build/fuchsia/test/flash_device.py b/build/fuchsia/test/flash_device.py
index fd3750ebd2..57db5d1f6d 100755
--- a/build/fuchsia/test/flash_device.py
+++ b/build/fuchsia/test/flash_device.py
@@ -43,7 +43,7 @@ def _get_system_info(target: Optional[str],
if running_unattended():
try:
boot_device(target, BootMode.REGULAR, serial_num)
- except (subprocess.CalledProcessError, RuntimeError):
+ except (subprocess.CalledProcessError, common.StateTransitionError):
logging.warning('Could not boot device. Assuming in ZEDBOOT')
return ('', '')
wait_cmd = common.run_ffx_command(('target', 'wait', '-t', '180'),
diff --git a/build/fuchsia/test/flash_device_unittests.py b/build/fuchsia/test/flash_device_unittests.py
index 485be54958..4fbaafdeb0 100755
--- a/build/fuchsia/test/flash_device_unittests.py
+++ b/build/fuchsia/test/flash_device_unittests.py
@@ -124,7 +124,8 @@ class FlashDeviceTest(unittest.TestCase):
mock.patch('flash_device.boot_device') as mock_boot, \
mock.patch('flash_device.get_system_info') as mock_sys_info, \
mock.patch('flash_device.subprocess.run'):
- mock_boot.side_effect = RuntimeError('Incorrect state')
+ mock_boot.side_effect = common.StateTransitionError(
+ 'Incorrect state')
self._ffx_mock.return_value.stdout = \
'[{"title": "Build", "child": [{"value": "wrong.version"}, ' \
'{"value": "wrong_product"}]}]'
diff --git a/build/rust/std/BUILD.gn b/build/rust/std/BUILD.gn
index fccf350a53..6ae92a31f2 100644
--- a/build/rust/std/BUILD.gn
+++ b/build/rust/std/BUILD.gn
@@ -239,6 +239,18 @@ if (toolchain_has_rust) {
ldflags = []
lib_dir = rebase_path("$prebuilt_rustc_sysroot/$sysroot_lib_subdir",
root_build_dir)
+
+ # We're unable to make these files regular gn dependencies because
+ # they're prebuilt. Instead, we'll pass them in the ldflags. This doesn't
+ # work for all types of build because ldflags propagate differently from
+ # actual dependencies and therefore can end up in different targets from
+ # the remap_alloc.cc above. For example, in a component build, we might
+ # apply the remap_alloc.cc file and these ldlags to shared object A,
+ # while shared object B (that depends upon A) might get only the ldflags
+ # but not remap_alloc.cc, and thus the build will fail. There is
+ # currently no known solution to this for the prebuilt stdlib - this
+ # problem does not apply with configurations where we build the stdlib
+ # ourselves, which is what we'll use in production.
foreach(lib, stdlib_files) {
this_file = "$lib_dir/lib$lib.rlib"
ldflags += [ this_file ]
diff --git a/build/util/LASTCHANGE b/build/util/LASTCHANGE
index 3f2f80edd1..59e488245f 100644
--- a/build/util/LASTCHANGE
+++ b/build/util/LASTCHANGE
@@ -1,2 +1,2 @@
-LASTCHANGE=da8c6824432694a6d2de51fae66134e79a5715d9-refs/heads/main@{#1132904}
+LASTCHANGE=f78fc195a7798b13df0c7d13ebb863e21c6905d3-refs/heads/main@{#1133572}
LASTCHANGE_YEAR=2023
diff --git a/build/util/LASTCHANGE.committime b/build/util/LASTCHANGE.committime
index 888acd5d40..5542e12cda 100644
--- a/build/util/LASTCHANGE.committime
+++ b/build/util/LASTCHANGE.committime
@@ -1 +1 @@
-1681963318 \ No newline at end of file
+1682047285 \ No newline at end of file
diff --git a/infra/specs/angle.json b/infra/specs/angle.json
index 9212dfe3fe..1372b4026c 100644
--- a/infra/specs/angle.json
+++ b/infra/specs/angle.json
@@ -1662,33 +1662,6 @@
{
"args": [
"--log=debug",
- "interpret",
- "among_us:catalyst_black:cut_the_rope:dota_underlords:fishdom:genshin_impact:harry_potter_hogwarts_mystery:manhattan_10:trex_200",
- "-L=2",
- "--show-test-stdout"
- ],
- "isolate_name": "angle_trace_interpreter_tests",
- "merge": {
- "script": "//testing/merge_scripts/standard_isolated_script_merge.py"
- },
- "name": "angle_trace_interpreter_tests",
- "swarming": {
- "can_use_on_swarming_builders": true,
- "containment_type": "AUTO",
- "dimension_sets": [
- {
- "gpu": "8086:9bc5-20.0.8",
- "os": "Ubuntu-18.04.6",
- "pool": "chromium.tests.gpu"
- }
- ],
- "service_account": "chromium-tester@chops-service-accounts.iam.gserviceaccount.com"
- },
- "test_id_prefix": "ninja://src/tests:angle_trace_interpreter_tests/"
- },
- {
- "args": [
- "--log=debug",
"--smoke-test-mode",
"--show-test-stdout",
"--use-gl=native",
@@ -2501,33 +2474,6 @@
{
"args": [
"--log=debug",
- "interpret",
- "among_us:catalyst_black:cut_the_rope:dota_underlords:fishdom:genshin_impact:harry_potter_hogwarts_mystery:manhattan_10:trex_200",
- "-L=2",
- "--show-test-stdout"
- ],
- "isolate_name": "angle_trace_interpreter_tests",
- "merge": {
- "script": "//testing/merge_scripts/standard_isolated_script_merge.py"
- },
- "name": "angle_trace_interpreter_tests",
- "swarming": {
- "can_use_on_swarming_builders": true,
- "containment_type": "AUTO",
- "dimension_sets": [
- {
- "gpu": "10de:2184-440.100",
- "os": "Ubuntu-18.04.5|Ubuntu-18.04.6",
- "pool": "chromium.tests.gpu"
- }
- ],
- "service_account": "chromium-tester@chops-service-accounts.iam.gserviceaccount.com"
- },
- "test_id_prefix": "ninja://src/tests:angle_trace_interpreter_tests/"
- },
- {
- "args": [
- "--log=debug",
"--smoke-test-mode",
"--show-test-stdout",
"--use-gl=native",
@@ -4502,34 +4448,6 @@
{
"args": [
"--log=debug",
- "interpret",
- "among_us:catalyst_black:cut_the_rope:dota_underlords:fishdom:genshin_impact:harry_potter_hogwarts_mystery:manhattan_10:trex_200",
- "-L=2",
- "--show-test-stdout"
- ],
- "isolate_name": "angle_trace_interpreter_tests",
- "merge": {
- "script": "//testing/merge_scripts/standard_isolated_script_merge.py"
- },
- "name": "angle_trace_interpreter_tests",
- "swarming": {
- "can_use_on_swarming_builders": true,
- "containment_type": "AUTO",
- "dimension_sets": [
- {
- "display_attached": "1",
- "gpu": "8086:9bc5-31.0.101.2111",
- "os": "Windows-10",
- "pool": "chromium.tests.gpu"
- }
- ],
- "service_account": "chromium-tester@chops-service-accounts.iam.gserviceaccount.com"
- },
- "test_id_prefix": "ninja://src/tests:angle_trace_interpreter_tests/"
- },
- {
- "args": [
- "--log=debug",
"--smoke-test-mode",
"--show-test-stdout",
"--use-gl=native",
@@ -5450,34 +5368,6 @@
{
"args": [
"--log=debug",
- "interpret",
- "among_us:catalyst_black:cut_the_rope:dota_underlords:fishdom:genshin_impact:harry_potter_hogwarts_mystery:manhattan_10:trex_200",
- "-L=2",
- "--show-test-stdout"
- ],
- "isolate_name": "angle_trace_interpreter_tests",
- "merge": {
- "script": "//testing/merge_scripts/standard_isolated_script_merge.py"
- },
- "name": "angle_trace_interpreter_tests",
- "swarming": {
- "can_use_on_swarming_builders": true,
- "containment_type": "AUTO",
- "dimension_sets": [
- {
- "display_attached": "1",
- "gpu": "10de:2184-27.21.14.5638",
- "os": "Windows-10-18363",
- "pool": "chromium.tests.gpu"
- }
- ],
- "service_account": "chromium-tester@chops-service-accounts.iam.gserviceaccount.com"
- },
- "test_id_prefix": "ninja://src/tests:angle_trace_interpreter_tests/"
- },
- {
- "args": [
- "--log=debug",
"--smoke-test-mode",
"--show-test-stdout",
"--use-gl=native",
diff --git a/infra/specs/test_suites.pyl b/infra/specs/test_suites.pyl
index 307978dfc1..f225677d07 100644
--- a/infra/specs/test_suites.pyl
+++ b/infra/specs/test_suites.pyl
@@ -772,18 +772,6 @@
}
},
- 'angle_trace_interpreter_isolated_scripts': {
- 'angle_trace_interpreter_tests': {
- 'args': [
- '--log=debug',
- 'interpret',
- 'among_us:catalyst_black:cut_the_rope:dota_underlords:fishdom:genshin_impact:harry_potter_hogwarts_mystery:manhattan_10:trex_200',
- '-L=2',
- '--show-test-stdout',
- ],
- },
- },
-
'angle_trace_perf_native_isolated_scripts': {
'angle_trace_perf_native_tests': {
'android_args': {
@@ -1189,7 +1177,6 @@
'angle_perf_smoke_isolated_scripts',
'angle_restricted_trace_gold_isolated_scripts',
'angle_restricted_trace_gold_interpreted_isolated_scripts',
- 'angle_trace_interpreter_isolated_scripts',
'angle_trace_perf_native_smoke_isolated_scripts',
'angle_trace_perf_vulkan_smoke_isolated_scripts',
],
diff --git a/scripts/code_generation_hashes/GL_CTS_(dEQP)_build_files.json b/scripts/code_generation_hashes/GL_CTS_(dEQP)_build_files.json
index 50c10c7fe1..d920d50f5a 100644
--- a/scripts/code_generation_hashes/GL_CTS_(dEQP)_build_files.json
+++ b/scripts/code_generation_hashes/GL_CTS_(dEQP)_build_files.json
@@ -18,7 +18,7 @@
"third_party/VK-GL-CTS/src/external/glslang/CMakeLists.txt":
"323b44bb52b08f5a937d6e7827667d34",
"third_party/VK-GL-CTS/src/external/jsoncpp/CMakeLists.txt":
- "7eb4055df9b15690be98a0c7e7e9c1d2",
+ "80cd4f898f759cebdeaa46552fcedddb",
"third_party/VK-GL-CTS/src/external/libpng/CMakeLists.txt":
"f0a31a5d1edcf912eea4668abf8c9c27",
"third_party/VK-GL-CTS/src/external/openglcts/CMakeLists.txt":
diff --git a/scripts/code_generation_hashes/Test_spec_JSON.json b/scripts/code_generation_hashes/Test_spec_JSON.json
index 69b9af7abe..f0eb879bf7 100644
--- a/scripts/code_generation_hashes/Test_spec_JSON.json
+++ b/scripts/code_generation_hashes/Test_spec_JSON.json
@@ -1,6 +1,6 @@
{
"infra/specs/angle.json":
- "c72b4f277e0188c2e30130c6514428d7",
+ "33a92e3287a38a423edb5f9e4c3c771b",
"infra/specs/generate_test_spec_json.py":
"b8dbb50c814b7fe05eb77cf6e376cee4",
"infra/specs/mixins.pyl":
@@ -8,7 +8,7 @@
"infra/specs/test_suite_exceptions.pyl":
"55886f8b6ae4122306ce42083c5126c7",
"infra/specs/test_suites.pyl":
- "05d9fcbb11fd192584d3c29b74af59cd",
+ "6e983ea4ea08d6032b834dd9d92ed090",
"infra/specs/variants.pyl":
"8cfcaa99fa07ad2a2d5d14f220fd5037",
"infra/specs/waterfalls.pyl":
diff --git a/src/common/base/anglebase/sha1.h b/src/common/base/anglebase/sha1.h
index a1bacd725c..4856557c73 100644
--- a/src/common/base/anglebase/sha1.h
+++ b/src/common/base/anglebase/sha1.h
@@ -6,6 +6,7 @@
#define ANGLEBASE_SHA1_H_
#include <stddef.h>
+#include <stdint.h>
#include <array>
#include <string>
diff --git a/src/libANGLE/Context.cpp b/src/libANGLE/Context.cpp
index 0b1e9f462a..d03a2625c3 100644
--- a/src/libANGLE/Context.cpp
+++ b/src/libANGLE/Context.cpp
@@ -10255,10 +10255,13 @@ void ErrorSet::validationError(angle::EntryPoint entryPoint, GLenum errorCode, c
{
ASSERT(errorCode != GL_NO_ERROR);
mErrors.insert(errorCode);
-
+ gl::LogSeverity severity = gl::LOG_INFO;
+#if defined(ANGLE_ENABLE_ASSERTS)
+ severity = gl::LOG_WARN;
+#endif // defined(ANGLE_ENABLE_ASSERTS)
mContext->getState().getDebug().insertMessage(GL_DEBUG_SOURCE_API, GL_DEBUG_TYPE_ERROR,
errorCode, GL_DEBUG_SEVERITY_HIGH, message,
- gl::LOG_INFO, entryPoint);
+ severity, entryPoint);
}
bool ErrorSet::empty() const
diff --git a/src/libANGLE/renderer/metal/mtl_utils.mm b/src/libANGLE/renderer/metal/mtl_utils.mm
index 2d2ee6c966..a94d4e2ac3 100644
--- a/src/libANGLE/renderer/metal/mtl_utils.mm
+++ b/src/libANGLE/renderer/metal/mtl_utils.mm
@@ -922,6 +922,8 @@ std::string CompileShaderLibraryToFile(const std::string &source,
"-sdk",
"macosx",
"metal",
+ "-std=macos-metal2.0",
+ "-mmacosx-version-min=10.13",
"-c",
metalFileName.value(),
"-o",
diff --git a/src/libANGLE/renderer/vulkan/ContextVk.cpp b/src/libANGLE/renderer/vulkan/ContextVk.cpp
index 77393113dd..1004f62526 100644
--- a/src/libANGLE/renderer/vulkan/ContextVk.cpp
+++ b/src/libANGLE/renderer/vulkan/ContextVk.cpp
@@ -3145,8 +3145,8 @@ angle::Result ContextVk::handleDirtyGraphicsDynamicFragmentShadingRate(
gl::ShadingRate shadingRate = getState().getShadingRate();
if (shadingRate == gl::ShadingRate::Undefined)
{
- // Shading rate has not been set. Nothing to do, early return.
- return angle::Result::Continue;
+ // Shading rate has not been set. Since this is dynamic state, set it to 1x1
+ shadingRate = gl::ShadingRate::_1x1;
}
const bool shadingRateSupported = mRenderer->isShadingRateSupported(shadingRate);
@@ -5652,7 +5652,10 @@ angle::Result ContextVk::syncState(const gl::Context *context,
}
break;
case gl::State::EXTENDED_DIRTY_BIT_SHADING_RATE:
- mGraphicsDirtyBits.set(DIRTY_BIT_DYNAMIC_FRAGMENT_SHADING_RATE);
+ if (getFeatures().supportsFragmentShadingRate.enabled)
+ {
+ mGraphicsDirtyBits.set(DIRTY_BIT_DYNAMIC_FRAGMENT_SHADING_RATE);
+ }
break;
default:
UNREACHABLE();
diff --git a/src/tests/BUILD.gn b/src/tests/BUILD.gn
index a0131e56b2..f2f4f7a86e 100644
--- a/src/tests/BUILD.gn
+++ b/src/tests/BUILD.gn
@@ -1214,6 +1214,17 @@ if (build_angle_deqp_tests && !is_fuchsia) {
"$deqp_path/framework/delibs/deutil",
"$deqp_path/framework/delibs/destream",
]
+
+ # https://github.com/KhronosGroup/VK-GL-CTS/commit/9f306457b48b3f8258ca44462003ef39b80a7515
+ if (is_clang) {
+ if (target_cpu == "arm") {
+ defines = [ "DE_FENV_ACCESS_ON=" ]
+ } else {
+ defines = [ "DE_FENV_ACCESS_ON=_Pragma(\"STDC FENV_ACCESS ON\")" ]
+ }
+ } else if (is_win) {
+ defines = [ "DE_FENV_ACCESS_ON=__pragma(fenv_access (on))" ]
+ }
}
angle_deqp_source_set("angle_deqp_framework_delibs") {
diff --git a/src/tests/angle_end2end_tests_expectations.txt b/src/tests/angle_end2end_tests_expectations.txt
index 469d01bed6..0150d97108 100644
--- a/src/tests/angle_end2end_tests_expectations.txt
+++ b/src/tests/angle_end2end_tests_expectations.txt
@@ -851,6 +851,8 @@ b/273271471 WIN INTEL VULKAN : ShaderAlgorithmTest.rgb_to_hsl_vertex_shader/* =
7994 IOS METAL : PixelLocalStorageTest.R32/ES3_Metal_EmulatePixelLocalStorage_DisableRasterOrderGroups = SKIP
7994 IOS METAL : PixelLocalStorageTest.RGBA8/ES3_Metal_EmulatePixelLocalStorage = SKIP
7994 IOS METAL : PixelLocalStorageTest.RGBA8/ES3_Metal_EmulatePixelLocalStorage_DisableRasterOrderGroups = SKIP
+7994 IOS METAL : PixelLocalStorageTest.TextureLevelsAndLayers/ES3_Metal_EmulatePixelLocalStorage = SKIP
+7994 IOS METAL : PixelLocalStorageTest.TextureLevelsAndLayers/ES3_Metal_EmulatePixelLocalStorage_DisableRasterOrderGroups = SKIP
7994 IOS METAL : PointSpritesTest.PointSizeAboveMaxIsClamped/ES2_Metal = SKIP
7994 IOS METAL : RobustBufferAccessWebGL2ValidationStateChangeTest.BindZeroSizeBufferThenDeleteBufferBug/ES3_Metal = SKIP
7994 IOS METAL : SamplerTypeMixTestES3.SamplerTypeMixDraw/ES3_Metal = SKIP
diff --git a/third_party/abseil-cpp/absl/base/options.h b/third_party/abseil-cpp/absl/base/options.h
index 50431087fc..5bfa27dcdb 100644
--- a/third_party/abseil-cpp/absl/base/options.h
+++ b/third_party/abseil-cpp/absl/base/options.h
@@ -94,7 +94,7 @@
// User code should not inspect this macro. To check in the preprocessor if
// absl::any is a typedef of std::any, use the feature macro ABSL_USES_STD_ANY.
-#define ABSL_OPTION_USE_STD_ANY 0
+#define ABSL_OPTION_USE_STD_ANY 2
// ABSL_OPTION_USE_STD_OPTIONAL
diff --git a/third_party/abseil-cpp/patches/0001-Turn-on-hardened-mode.patch b/third_party/abseil-cpp/patches/0001-Turn-on-hardened-mode.patch
index 4ce90d3300..ea315bfa8d 100644
--- a/third_party/abseil-cpp/patches/0001-Turn-on-hardened-mode.patch
+++ b/third_party/abseil-cpp/patches/0001-Turn-on-hardened-mode.patch
@@ -17,15 +17,6 @@ diff --git a/third_party/abseil-cpp/absl/base/options.h b/third_party/abseil-cpp
index 230bf1eecc4a4..1641271cd3ff9 100644
--- a/third_party/abseil-cpp/absl/base/options.h
+++ b/third_party/abseil-cpp/absl/base/options.h
-@@ -100,7 +100,7 @@
- // User code should not inspect this macro. To check in the preprocessor if
- // absl::any is a typedef of std::any, use the feature macro ABSL_USES_STD_ANY.
-
--#define ABSL_OPTION_USE_STD_ANY 2
-+#define ABSL_OPTION_USE_STD_ANY 0
-
-
- // ABSL_OPTION_USE_STD_OPTIONAL
@@ -127,7 +127,7 @@
// absl::optional is a typedef of std::optional, use the feature macro
// ABSL_USES_STD_OPTIONAL.
diff --git a/third_party/vulkan-deps/DEPS b/third_party/vulkan-deps/DEPS
index ae89f456ba..181f33b614 100644
--- a/third_party/vulkan-deps/DEPS
+++ b/third_party/vulkan-deps/DEPS
@@ -9,7 +9,7 @@ vars = {
'chromium_git': 'https://chromium.googlesource.com',
# Current revision of glslang, the Khronos SPIRV compiler.
- 'glslang_revision': 'f46f4b192a02dd7797e3e6c1053faeb6dc356b4f',
+ 'glslang_revision': 'b8955549ef3c5c247573573ffbeb0ebde857529a',
# Current revision of spirv-cross, the Khronos SPIRV cross compiler.
'spirv_cross_revision': 'fc9bee27f445644635e83ef111ef54944bb6e3af',
@@ -21,16 +21,16 @@ vars = {
'spirv_tools_revision': '25ad5e19f193429b737433d5f6151062ddbc1680',
# Current revision of Khronos Vulkan-Headers.
- 'vulkan_headers_revision': '4c304fac642d745049259d4b85dd86960f09941a',
+ 'vulkan_headers_revision': '8a397558c4d2a4bf9e64e900c45a7e65664c32b2',
# Current revision of Khronos Vulkan-Loader.
- 'vulkan_loader_revision': 'f035e57c171ce9009f2c47b5488a66c653843501',
+ 'vulkan_loader_revision': '4be91725abb01e8004be966203b95a181c06e1a0',
# Current revision of Khronos Vulkan-Tools.
'vulkan_tools_revision': 'db7475424c5deed3a8d2acf1b5022ad4accf206f',
# Current revision of Khronos Vulkan-ValidationLayers.
- 'vulkan_validation_revision': '6a05570bab896f6a9da1608795cb27c41c8d7f6a',
+ 'vulkan_validation_revision': 'c827791afe7bbf9f45ff1255545987386c5c9226',
}
deps = {
diff --git a/third_party/vulkan-deps/glslang/src/.appveyor.yml b/third_party/vulkan-deps/glslang/src/.appveyor.yml
deleted file mode 100644
index 76ab1f07b5..0000000000
--- a/third_party/vulkan-deps/glslang/src/.appveyor.yml
+++ /dev/null
@@ -1,108 +0,0 @@
-# Windows Build Configuration for AppVeyor
-# http://www.appveyor.com/docs/appveyor-yml
-
-# build version format
-version: "{build}"
-
-os: Visual Studio 2019
-
-platform:
- - x64
-
-configuration:
- - Debug
- - Release
-
-branches:
- only:
- - main
-
-# changes to these files don't need to trigger testing
-skip_commits:
- files:
- - README.md
- - README-spirv-remap.txt
- - LICENSE.txt
- - CODE_OF_CONDUCT.md
- - BUILD.*
- - WORKSPACE
- - kokoro/*
- - make-revision
- - Android.mk
- - _config.yml
-
-# Travis advances the main-tot tag to current top of the tree after
-# each push into the main branch, because it relies on that tag to
-# upload build artifacts to the main-tot release. This will cause
-# double testing for each push on Appveyor: one for the push, one for
-# the tag advance. Disable testing tags.
-skip_tags: true
-
-clone_depth: 5
-
-matrix:
- fast_finish: true # Show final status immediately if a test fails.
-
-# scripts that run after cloning repository
-install:
- - C:/Python27/python.exe update_glslang_sources.py
- - set PATH=C:\ninja;C:\Python36;%PATH%
- - git clone https://github.com/google/googletest.git External/googletest
-
-build:
- parallel: true # enable MSBuild parallel builds
- verbosity: minimal
-
-build_script:
- - mkdir build && cd build
- - cmake -G "Visual Studio 16 2019" -A x64 -DCMAKE_INSTALL_PREFIX=install ..
- - cmake --build . --config %CONFIGURATION% --target install
-
-test_script:
- - ctest -C %CONFIGURATION% --output-on-failure
- - cd ../Test && bash runtests
- - cd ../build
-
-after_test:
- # For debug build, the generated dll has a postfix "d" in its name.
- - ps: >-
- If ($env:configuration -Match "Debug") {
- $env:SUFFIX="d"
- } Else {
- $env:SUFFIX=""
- }
- - cd install
- # Zip all glslang artifacts for uploading and deploying
- - 7z a glslang-main-windows-"%PLATFORM%"-"%CONFIGURATION%".zip
- bin\glslangValidator.exe
- bin\spirv-remap.exe
- include\glslang\*
- lib\GenericCodeGen%SUFFIX%.lib
- lib\glslang%SUFFIX%.lib
- lib\glslang-default-resource-limits%SUFFIX%.lib
- lib\HLSL%SUFFIX%.lib
- lib\MachineIndependent%SUFFIX%.lib
- lib\OGLCompiler%SUFFIX%.lib
- lib\OSDependent%SUFFIX%.lib
- lib\SPIRV%SUFFIX%.lib
- lib\SPVRemapper%SUFFIX%.lib
- lib\SPIRV-Tools%SUFFIX%.lib
- lib\SPIRV-Tools-opt%SUFFIX%.lib
-
-artifacts:
- - path: build\install\*.zip
- name: artifacts-zip
-
-deploy:
- - provider: GitHub
- auth_token:
- secure: YglcSYdl0TylEa59H4K6lylBEDr586NAt2EMgZquSo+iuPrwgZQuJLPCoihSm9y6
- release: main-tot
- description: "Continuous build of the latest main branch by Appveyor and Github"
- artifact: artifacts-zip
- draft: false
- prerelease: false
- force_update: true
- on:
- branch: main
- APPVEYOR_BUILD_WORKER_IMAGE: Visual Studio 2019
diff --git a/third_party/vulkan-deps/glslang/src/Test/baseResults/300layout.vert.out b/third_party/vulkan-deps/glslang/src/Test/baseResults/300layout.vert.out
index 527425b37d..e1ec452474 100644
--- a/third_party/vulkan-deps/glslang/src/Test/baseResults/300layout.vert.out
+++ b/third_party/vulkan-deps/glslang/src/Test/baseResults/300layout.vert.out
@@ -1,6 +1,6 @@
300layout.vert
ERROR: 0:7: 'vertex input arrays' : not supported with this profile: es
-ERROR: 0:8: 'in' : cannot be a structure or array
+ERROR: 0:8: 'in' : cannot be a structure
ERROR: 0:8: 's' : A structure containing an array is not allowed as input in ES
ERROR: 0:8: 'vertex input arrays' : not supported with this profile: es
ERROR: 0:8: 'location' : overlapping use of location 10
diff --git a/third_party/vulkan-deps/glslang/src/glslang/MachineIndependent/ParseHelper.cpp b/third_party/vulkan-deps/glslang/src/glslang/MachineIndependent/ParseHelper.cpp
index 921ddcbeec..6e79f0c2e7 100644
--- a/third_party/vulkan-deps/glslang/src/glslang/MachineIndependent/ParseHelper.cpp
+++ b/third_party/vulkan-deps/glslang/src/glslang/MachineIndependent/ParseHelper.cpp
@@ -4013,7 +4013,7 @@ void TParseContext::globalQualifierTypeCheck(const TSourceLoc& loc, const TQuali
switch (language) {
case EShLangVertex:
if (publicType.basicType == EbtStruct) {
- error(loc, "cannot be a structure or array", GetStorageQualifierString(qualifier.storage), "");
+ error(loc, "cannot be a structure", GetStorageQualifierString(qualifier.storage), "");
return;
}
if (publicType.arraySizes) {
diff --git a/third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan.hpp b/third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan.hpp
index 39a6549379..a7e858a319 100644
--- a/third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan.hpp
+++ b/third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan.hpp
@@ -114,7 +114,7 @@ extern "C" __declspec( dllimport ) FARPROC __stdcall GetProcAddress( HINSTANCE h
# include <span>
#endif
-static_assert( VK_HEADER_VERSION == 247, "Wrong VK_HEADER_VERSION!" );
+static_assert( VK_HEADER_VERSION == 248, "Wrong VK_HEADER_VERSION!" );
// 32-bit vulkan is not typesafe for non-dispatchable handles, so don't allow copy constructors on this platform by default.
// To enable this feature on 32-bit platforms please define VULKAN_HPP_TYPESAFE_CONVERSION
diff --git a/third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan_core.h b/third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan_core.h
index e30fe49fd7..cf243a971a 100644
--- a/third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan_core.h
+++ b/third_party/vulkan-deps/vulkan-headers/src/include/vulkan/vulkan_core.h
@@ -68,7 +68,7 @@ extern "C" {
#define VK_API_VERSION_1_0 VK_MAKE_API_VERSION(0, 1, 0, 0)// Patch version should always be set to 0
// Version of this file
-#define VK_HEADER_VERSION 247
+#define VK_HEADER_VERSION 248
// Complete version of this file
#define VK_HEADER_VERSION_COMPLETE VK_MAKE_API_VERSION(0, 1, 3, VK_HEADER_VERSION)
diff --git a/build/fuchsia/test/common.py b/build/fuchsia/test/common.py
index 2ac717302f..4377956d73 100644
--- a/build/fuchsia/test/common.py
+++ b/build/fuchsia/test/common.py
@@ -59,6 +59,14 @@ _STATE_TO_BOOTMODE = {
_BOOTMODE_TO_STATE = {value: key for key, value in _STATE_TO_BOOTMODE.items()}
+class StateNotFoundError(Exception):
+ """Raised when target's state cannot be found."""
+
+
+class StateTransitionError(Exception):
+ """Raised when target does not transition to desired state."""
+
+
def _state_string_to_state(state_str: str) -> TargetState:
state_str = state_str.strip().lower()
if state_str == 'product':
@@ -91,10 +99,10 @@ def get_target_state(target_id: Optional[str],
TargetState of the given node, if found.
Raises:
RuntimeError: If target cannot be found, or default target is not
defined if |target_id| is not given.
"""
- for _ in range(num_attempts):
+ for i in range(num_attempts):
targets = json.loads(
run_ffx_command(('target', 'list'),
check=True,
@@ -109,14 +117,16 @@ def get_target_state(target_id: Optional[str],
if serial_num == target['serial']:
# Should only return Fastboot.
return _state_string_to_state(target['target_state'])
- time.sleep(10)
+ # Do not sleep for last attempt.
+ if i < num_attempts - 1:
+ time.sleep(10)
# Could not find a state for given target.
error_target = target_id
if target_id is None:
error_target = 'default target'
- raise RuntimeError(f'Could not find state for {error_target}.')
+ raise StateNotFoundError(f'Could not find state for {error_target}.')
def set_ffx_isolate_dir(isolate_dir: str) -> None:
@@ -478,6 +488,8 @@ def boot_device(target_id: Optional[str],
target_id: Optional target_id of device.
mode: Desired boot mode.
must_boot: Forces device to boot, regardless of current state.
+ Raises:
+ StateTransitionError: When final state of device is not desired.
"""
# Skip boot call if already in the state and not skipping check.
state = get_target_state(target_id, serial_num, num_attempts=3)
@@ -501,7 +513,7 @@ def boot_device(target_id: Optional[str],
if local_state != current_state:
# Changed states - can continue
break
- except RuntimeError:
+ except StateNotFoundError:
logging.debug('Device disconnected...')
if current_state != TargetState.DISCONNECTED:
# Changed states - can continue
@@ -519,7 +531,7 @@ def boot_device(target_id: Optional[str],
local_state = get_target_state(target_id, serial_num)
if local_state == wanted_state:
return local_state
- except RuntimeError:
+ except StateNotFoundError:
logging.warning('Could not find target state.'
' Sleeping then retrying...')
finally:
@@ -530,7 +542,7 @@ def boot_device(target_id: Optional[str],
(lambda: _boot_device_ffx(target_id, serial_num, state, mode)), state)
if state == TargetState.DISCONNECTED:
- raise RuntimeError('Target could not be found!')
+ raise StateNotFoundError('Target could not be found!')
if state == wanted_state:
return
@@ -544,7 +556,7 @@ def boot_device(target_id: Optional[str],
(lambda: _boot_device_dm(target_id, serial_num, state, mode)), state)
if state != wanted_state:
- raise RuntimeError(
+ raise StateTransitionError(
f'Could not get device to desired state. Wanted {wanted_state},'
f' got {state}')
logging.debug('Got desired state: %s', state)
@@ -580,11 +592,12 @@ def _boot_device_dm(target_id: Optional[str], serial_num: Optional[str],
current_state: TargetState, mode: BootMode):
# Can only use DM if device is in regular boot.
if current_state != TargetState.PRODUCT:
+ if mode == BootMode.REGULAR:
+ raise StateTransitionError('Cannot boot to Regular via DM - '
+ 'FFX already failed to do so.')
# Boot to regular.
_boot_device_ffx(target_id, serial_num, current_state,
BootMode.REGULAR)
- if mode == BootMode.REGULAR:
- return
ssh_prefix = get_ssh_prefix(get_ssh_address(target_id))
@@ -91,10 +99,10 @@ def get_target_state(target_id: Optional[str],
TargetState of the given node, if found.
Raises:
- RuntimeError: If target cannot be found, or default target is not
+ StateNotFoundError: If target cannot be found, or default target is not
defined if |target_id| is not given.
"""